"""Synapse-compatible sensor emulator package."""

from sensor_emulator.lidar_collector import main as lidar_collector_main
from sensor_emulator.mavlink import MavlinkEmulator, MavlinkTelemetryConfig
from sensor_emulator.radar import RadarEmulator, RadarEmulatorConfig

__all__ = [
    "RadarEmulator",
    "RadarEmulatorConfig",
    "MavlinkEmulator",
    "MavlinkTelemetryConfig",
    "lidar_collector_main",
]
